/* $Id: draw_gbl.h 1108 2011-01-23 18:10:46Z martin $ */

/* draw_gbl.h - global definitions for DRAWxtl */

CRYSTAL  *drvui = NULL;

/* global variables for atom lists */

int natom;                  /* number of different types of atoms */
int ncell;                  /* number of atoms in asymmetric unit */
float *xypos;               /* master list fractional coordinates */
float *xypos_nm = NULL;     /* master list of fractional coordinates (not modulated) */
float *o_vert;              /* crystal coordinates of saved vertices */
float *o_vert_nm = NULL;    /* crystal coordinates of saved vertices (not modulated) */
float *s_vert;              /* saved coordinates of vertices */
int *vert_sym_no;           /* saved symmetry operator number */
int *vert_sym_nos;           /* saved symmetry operator number, with sign */
int *poly_list;             /* storage for polygon corner pointers */
int nvert;                  /* number of vertices in list */
int NvertM;                 /* number of vertices in master atom list */

/* global variables for spheres and ellipsoids */

int do_ellipsoids;				 /* non-zero if ellipsoids to be drawn */
int El_Cutout;					 /* True if ellipsoids to have an octant removed */
float Sphere_Mult;				 /* Multiplier for Sphere Size */
float SpMult;					 /* initialization for Sphere_Mult */

/* global variables for polyhedra, planes and bonds */

int draw_list;					 /* number of items in polygon draw list */
int *vertex_list;				 /* storage for vertices about a cation */
int numb_list;					 /* number in polygon list */
int domolcomp;					 /* non-zero if molecule completion requested */

/* global variables that control size and orientation of output object */

float DepthCue;			 /* scale for Z-dependent thickness of edges */
float boxlim[3];		 /* half limits of plotting box */
float origin[3];		 /* position of plotting origin */
double G_Rot[3][3];		 /* Grand rotation matrix - transforms from Cartesian to picture */
float POV_Max[3];		 /* Maximum limits of POV after rotation */
float POV_Min[3];		 /* Minimum limits of POV after rotation */
int boxflag;			 /* Non-zero if 'bounds' command given */
int packflag;			 /* Non-zero if 'pack' command given */
int clipflag;			 /* Non-zero if 'clip' command given */
int docell;                      /* non-zero if unit-cell edges to be drawn */
int Display_axes;		 /* non-zero if axial triple to be drawn */
int Color_Warning;		 /* Warning flag for non-standard color */
float Magnification;		 /* Magnification factor for image */
float Scale;			 /* Scale of diagram */
float offset[3];		 /* offset for vector triple */
float Text_Size;		 /* Size to make axis label text */
int Options;			 /* Place to save command-line options flags */
float rad_cell;			 /* radius of unit cell framebars */
int edges;                       /* draw thin lines around the edges of polyhedra */
float rad_edge;			 /* default radius of cylinders on polyhedron edges */
float xrot, yrot, zrot;		 /* view rotation angles */
int Unit_Cell;			 /* non-zero if unit cell to be drawn */
int no_comment;			 /* non-zero to inhibit comment lines in VRML */
int M_cameras;			 /* non-zero to inhibit multiple cameras */
int Vrml2;                       /* non-zero to generate VRML97 (VRML2) output */
int X3D;			 /* non-zero to generate X3D variant of VRML2 */
float printdist;		 /* Distance limit for tabulated output */
int Labels;                      /* True if labels should be output */

int gl_view = 1;		 /* if true, generate openGL view */

int slabmode=0;
float slabx1,slaby1,slabz1,slabx2,slaby2,slabz2;
float slabx3,slaby3,slabz3,slabx4,slaby4,slabz4;
float slabv[24];

/* openGL cursor stuff */
int cur_show = 0;                              /* true = show cursor; 0=no */
float cur_cen[3] = {0.25f, 0.25f, 0.25f};      /* location of cursor (fractional coordinates) */
int cur_atom[4];                 /* sequence numbers of last four atoms under cursor */
char cur_name[4][10];            /* name of atom under cursor */
float dist12 = 0.0;
float dist23 = 0.0;
float dist34 = 0.0;
float ang123 = 0.0;
float ang234 = 0.0;
float torsion_ang=0.0;
float cur_step = 0.5f;                         /* amount to jump cursor in A */

#include "drawmap.h"                           /* Fourier map stuff */

int ReadFourMap = 0;                           /* true if a Fourier map has been read */

float * FourierPt = NULL;                      /* pointer to Fourier map contents */

float map_a, map_b, map_c, map_alpha, map_beta, map_gamma; /* cell parameters for map, read from .grd file*/ 
                                               /* not checked against structure, but perhaps should be */
int  mapstep_a, mapstep_b, mapstep_c;          /* grid steps along each cell axis, read from .grd file*/ 

float xMin=0.0f;                               /* bounding box for map */
float xMax=1.0f;
float yMin=0.0f;
float yMax=1.0f;
float zMin=0.0f;
float zMax=1.0f;
float x4Val,x5Val,x6Val;        /* coordinates of map intersection with superspace */
float x4step,x5step,x6step;
char FourierFileName[256];
int FourierMapType;
int ShowMapLegend;
MAP_INFO Map_Info;

#ifdef OPENGL
GLuint crystalDL;
GLdouble modelMatrix[16];
GLdouble projMatrix[16];
GLint viewport[4];
#endif
int omit1[1000],omit2[1000],omit3[1000];
int nomits=0;
int gl_width = 700;
int gl_height = 700;
float xrot_i, yrot_i, zrot_i;
float gl_size=99999.0f;
#ifdef OPENGL
int gl_oldx = 0, gl_oldy = 0, gl_oldz = 0;	/* cursor position at beginning of rotation */
int gl_xymotion = 0, gl_zmotion = 0;
float gl_pos_x = 0, gl_pos_y = 0., gl_pos_z = 0.;
int gl_ortho=0;
float gl_offset = 1.0;
static GLuint selectBuf[BUFSIZE];
#endif

int view_inst = 1;

QUAT Spin;              /* quaternion incremental rotation */
QUAT Rotq;
int Mx;                 /* place where mouse is now */
int My;
int Oldx;               /* place where mouse used to be */
int Oldy;
float Tbsize;           /* fraction of window to fill with trackball */
float Mscale;           /* mouse movement multiplier */
int Event = 0;          /* mouse button and modifier keys */
XYZ Trans;              /* total translation */
int changed;            /* if the view changed */
int idle_redraw_;       /* call redraw() in any case */
int c_pick;		/* last label selected for dragging */
int g_Quick;
